==> synimport-8.x-1.03.tar.gz: synimport/src/Service/Product.php <==
<?php

namespace Drupal\synimport\Service;

use Drupal\Core\Config\FileStorage;

/**
 * Product import class.
 *
 * @internal
 *   For internal usage by the Commerce synimport module.
 */
class Product implements ImportInterface {
  /**
   * Global directory variable.
   *
   * @var string
   */
  protected $directory;

  /**
   * Service for service.
   *
   * @var Drupal\synimport\Service\CreateEntity
   */
  protected $createEntity;

  /**
   * Controller constructor.
   */
  public function __construct(ImportInterface $createEntity) {
    $this->createEntity = $createEntity;
  }

  /**
   * Search for created product.
   */
  private function getProductFromBase(string $unique_name) {
    $products = \Drupal::entityTypeManager()->getStorage('commerce_product')->loadByProperties(['field_unique_name' => $unique_name]);
    $product = array_shift($products);
    return $product ?? NULL;
  }

  /**
   * Search for products_array in $this->directory/products.
   */
  private function getProductFromFile(string $unique_name) {
    $sourceProducts = new FileStorage($this->directory . '/products');
    foreach ($sourceProducts->listAll() as $file) {
      $product_array = $sourceProducts->read($file);
      if ($product_array['field_unique_name'] == $unique_name) {
        break;
      }
    }
    return $product_array;
  }

  /**
   * Import Products.
   */
  public function import(string $directory) {
    $this->directory = $directory;
    $sourceProducts = new FileStorage($directory . '/products');
    foreach ($sourceProducts->listAll() as $file) {
      $product_array = $sourceProducts->read($file);
      $this->updateCreateProduct($product_array);
    }
  }

  /**
   * Update or Create Products.
   */
  private function updateCreateProduct(array $product_array) {
    $created_product = $this->getProductFromBase($product_array['field_unique_name']);
    if (!($created_product)) {
      $this->createProduct($product_array, 'full_create');
    }
    elseif (!empty($product_array['related_products'])) {
      $created_product_id = $created_product->id();
      $this->setRelated($created_product_id, $product_array['related_products']);
    }
  }

  /**
   * Create product.
   */
  private function createProduct(array $product_array, string $statement = 'full_create') {
    if ($statement == 'full_create') {
      $created_product_id = $this->createEntity->create($product_array, 'commerce_product')->id();
      if (!empty($product_array['related_products'])) {
        $this->setRelated($created_product_id, $product_array['related_products']);
      }
    }
    elseif ($statement == 'only_as_related') {
      $created_product = $this->getProductFromBase($product_array['field_unique_name']);
      if ($created_product) {
        return $created_product->id();
      }
      $created_product_id = $this->createEntity->create($product_array, 'commerce_product')->id();
    }
    return $created_product_id;
  }

  /**
   * Create Related Products.
   */
  private function setRelated(string $created_product_id, array $related_products) {
    $storage = \Drupal::entityTypeManager()->getStorage('commerce_product');
    $products_ids = [];
    foreach ($related_products as $unique_name) {
      $product_array = $this->getProductFromFile($unique_name);
      if (!empty($product_array)) {
        $products_ids[] = $this->createProduct($product_array, 'only_as_related');
      }
    }
    $created_product = $storage->load($created_product_id);
    $created_product->set("field_rf_product", $products_ids);
    $created_product->save();
  }

}

==> synimport-8.x-1.51.tar.gz: synimport/src/Service/Product.php <==
<?php

namespace Drupal\synimport\Service;

use Drupal\Core\Config\FileStorage;

/**
 * Product import class.
 *
 * @internal
 *   For internal usage by the Commerce synimport module.
 */
class Product implements ImportInterface {
  /**
   * Global directory variable.
   *
   * @var string
   */
  protected $directory;

  /**
   * Service for service.
   *
   * @var Drupal\synimport\Service\CreateEntity
   */
  protected $createEntity;

  /**
   * Controller constructor.
   */
  public function __construct(ImportInterface $createEntity) {
    $this->createEntity = $createEntity;
  }

  /**
   * Search for created product.
   */
  private function getProductFromBase(string $unique_name) {
    $products = \Drupal::entityTypeManager()->getStorage('commerce_product')->loadByProperties(['field_unique_name' => $unique_name]);
    $product = array_shift($products);
    return $product ?? NULL;
  }

  /**
   * Search for products_array in $this->directory/products.
   */
  private function getProductFromFile(string $unique_name) {
    $sourceProducts = new FileStorage($this->directory);
    foreach ($sourceProducts->listAll() as $file) {
      $product_array = $sourceProducts->read($file);
      if ($product_array['field_unique_name'] == $unique_name) {
        break;
      }
    }
    return $product_array;
  }

  /**
   * Import Products.
   */
  public function import(string $directory) {
    $this->directory = $directory;
    $sourceProducts = new FileStorage($directory);
    foreach ($sourceProducts->listAll() as $file) {
      $product_array = $sourceProducts->read($file);
      $this->updateCreateProduct($product_array);
    }
  }

  /**
   * Update or Create Products.
   */
  private function updateCreateProduct(array $product_array) {
    $created_product = $this->getProductFromBase($product_array['field_unique_name']);
    if (!($created_product)) {
      $this->createProduct($product_array, 'full_create');
    }
    elseif (!empty($product_array['related_products'])) {
      $created_product_id = $created_product->id();
      $this->setRelated($created_product_id, $product_array['related_products']);
    }
  }

  /**
   * Create product.
   */
  private function createProduct(array $product_array, string $statement = 'full_create') {
    if ($statement == 'full_create') {
      $created_product_id = $this->createEntity->create($product_array, 'commerce_product')->id();
      if (!empty($product_array['related_products'])) {
        $this->setRelated($created_product_id, $product_array['related_products']);
      }
    }
    elseif ($statement == 'only_as_related') {
      $created_product = $this->getProductFromBase($product_array['field_unique_name']);
      if ($created_product) {
        return $created_product->id();
      }
      $created_product_id = $this->createEntity->create($product_array, 'commerce_product')->id();
    }
    return $created_product_id;
  }

  /**
   * Create Related Products.
   */
  private function setRelated(string $created_product_id, array $related_products) {
    $storage = \Drupal::entityTypeManager()->getStorage('commerce_product');
    $products_ids = [];
    foreach ($related_products as $unique_name) {
      $product_array = $this->getProductFromFile($unique_name);
      if (!empty($product_array)) {
        $products_ids[] = $this->createProduct($product_array, 'only_as_related');
      }
    }
    $created_product = $storage->load($created_product_id);
    $created_product->set("field_rf_product", $products_ids);
    $created_product->save();
  }

}
